searchData={"items":[{"type":"module","title":"LogflareEx","doc":"Documentation for `LogflareEx`.","ref":"LogflareEx.html"},{"type":"function","title":"LogflareEx.client/1","doc":"Creates a client for interacting with Logflare.\n\nSee `LogflareEx.Client`.","ref":"LogflareEx.html#client/1"},{"type":"function","title":"LogflareEx.count_queued_events/0","doc":"Returns a count of all queued events.","ref":"LogflareEx.html#count_queued_events/0"},{"type":"function","title":"LogflareEx.flush/1","doc":"Performs a flush for a given client. Attempts to clear the queue of events for the given client.","ref":"LogflareEx.html#flush/1"},{"type":"function","title":"LogflareEx.send_batched_event/2","doc":"Sends a batched event.\n\nSee `send_batched_events/2`","ref":"LogflareEx.html#send_batched_event/2"},{"type":"function","title":"LogflareEx.send_batched_events/2","doc":"Sends events in batches. Configuration of the batching is dependent on the provided client.\n\nBatched events are cached locally and flushed at regular intervals.\n\n#","ref":"LogflareEx.html#send_batched_events/2"},{"type":"function","title":"Example - LogflareEx.send_batched_events/2","doc":"```elixir\n# create a client\niex> client = LogflareEx.client()\n%LogflareEx.Client{...}\n\n# singular event\niex> LogflareEx.send_batched_event(client, %{...})\n:ok\n\n# list of events\niex> LogflareEx.send_batched_event(client, [%{...}, ...])\n:ok\n```","ref":"LogflareEx.html#send_batched_events/2-example"},{"type":"function","title":"LogflareEx.send_event/2","doc":"Send a singular event to Logflare.\n\nSee `send_events/2`\n\nNo local caching is performed. This is less efficient than batching events.","ref":"LogflareEx.html#send_event/2"},{"type":"function","title":"LogflareEx.send_events/2","doc":"Sends events directly to the Logflare API without local caching. All batching configurations on the client will be ignored.\n\nIt is advised to use `send_batched_events/2` instead to spread out API requests.\n\n#","ref":"LogflareEx.html#send_events/2"},{"type":"function","title":"Example - LogflareEx.send_events/2","doc":"```elixir\niex> client = LogflareEx.client()\n%LogflareEx.Client{...}\n\n# singular event\niex> LogflareEx.send_event(client, %{my: \"event\"})\n{:ok, %{\"message\"=> \"Logged!}}\n\n# multiple events\niex> LogflareEx.send_events(client, [%{my: \"event\"}, ...])\n{:ok, %{\"message\"=> \"Logged!}}\n\n# a tesla result will be returned on error\niex> client |> LogflareEx.send_event(%{my: \"event\"})\n{:error, %Tesla.Env{...}}\n\n```","ref":"LogflareEx.html#send_events/2-example"},{"type":"module","title":"LogflareEx.Batcher","doc":"Batching cache is an Etso repo, `LogflareEx.Repo`, and stores all events to be sent to the Logflare service.\n\nThere are 2 states that an event can be in:\n- pending\n- inflight\n\nIf an event is inflight, it will have an `:inflight_at` timestamp stored on the struct.","ref":"LogflareEx.Batcher.html"},{"type":"function","title":"LogflareEx.Batcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LogflareEx.Batcher.html#child_spec/1"},{"type":"function","title":"LogflareEx.Batcher.create_event/1","doc":"Creates an event in the batching cache. This event will be considered as pending if it does not have an `:inflight_at` value set.\n\nAn event should only be created after all payload manipulations has been performed. The payload will be stored on the `:body` key.\n\nAll timestamp fields internally on the struct are NaiveDateTime.\n\nRequired fields:\n- :body\n- :source_token or :source_name","ref":"LogflareEx.Batcher.html#create_event/1"},{"type":"function","title":"LogflareEx.Batcher.delete_all_events/0","doc":"Deletes all events in the cache, regardless of the status.","ref":"LogflareEx.Batcher.html#delete_all_events/0"},{"type":"function","title":"LogflareEx.Batcher.delete_event/1","doc":"Deletes a single event in the cache.\n\n#","ref":"LogflareEx.Batcher.html#delete_event/1"},{"type":"function","title":"Example - LogflareEx.Batcher.delete_event/1","doc":"```elixir\niex> delete_event(event)\n{:ok, %BatchedEvent{...}}\n```","ref":"LogflareEx.Batcher.html#delete_event/1-example"},{"type":"function","title":"LogflareEx.Batcher.flush/1","doc":"Performs a flush for the given source.\n\nAccepts the following filters: `:source_name` or `:source_token`\n\nFlush is performed asyncronously.","ref":"LogflareEx.Batcher.html#flush/1"},{"type":"function","title":"LogflareEx.Batcher.list_events_by/2","doc":"Lists all events within the cache. All arguments provided are considered additive filters.\n\n#","ref":"LogflareEx.Batcher.html#list_events_by/2"},{"type":"function","title":"Example - LogflareEx.Batcher.list_events_by/2","doc":"```elixir\nlist_events_by(:pending)\nlist_events_by(:all)\nlist_events_by(:inflight)\nlist_events_by(:all, source_token: \"...\")\nlist_events_by(:all, source_name: \"...\")\nlist_events_by(:all, source_name: \"...\", limit: 5)\n```\n\n#","ref":"LogflareEx.Batcher.html#list_events_by/2-example"},{"type":"function","title":"Limitations - LogflareEx.Batcher.list_events_by/2","doc":"Etso does not support the Ecto.Query `:limit` option, hence filtering is done post result fetch.","ref":"LogflareEx.Batcher.html#list_events_by/2-limitations"},{"type":"function","title":"LogflareEx.Batcher.start_link/1","doc":"","ref":"LogflareEx.Batcher.html#start_link/1"},{"type":"function","title":"LogflareEx.Batcher.update_event/2","doc":"Updates the event within the batching cache.","ref":"LogflareEx.Batcher.html#update_event/2"},{"type":"function","title":"LogflareEx.Batcher.via/1","doc":"Returns the via for each partitioned Batcher. Accepts a `source_token` or `source_name` filter or a `%LogflareEx.Client{}` struct.\n\n#","ref":"LogflareEx.Batcher.html#via/1"},{"type":"function","title":"Example - LogflareEx.Batcher.via/1","doc":"```elixir\nvia(source_name: \"my source\")\nvia(source_token: \"some-uuid\")\nvia(%LogflareEx.Client{...})\n```","ref":"LogflareEx.Batcher.html#via/1-example"},{"type":"module","title":"LogflareEx.BatcherSup","doc":"","ref":"LogflareEx.BatcherSup.html"},{"type":"function","title":"LogflareEx.BatcherSup.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LogflareEx.BatcherSup.html#child_spec/1"},{"type":"function","title":"LogflareEx.BatcherSup.count_batchers/0","doc":"","ref":"LogflareEx.BatcherSup.html#count_batchers/0"},{"type":"function","title":"LogflareEx.BatcherSup.ensure_started/1","doc":"","ref":"LogflareEx.BatcherSup.html#ensure_started/1"},{"type":"function","title":"LogflareEx.BatcherSup.start_batcher/1","doc":"","ref":"LogflareEx.BatcherSup.html#start_batcher/1"},{"type":"function","title":"LogflareEx.BatcherSup.start_link/1","doc":"","ref":"LogflareEx.BatcherSup.html#start_link/1"},{"type":"function","title":"LogflareEx.BatcherSup.terminate_batchers/0","doc":"","ref":"LogflareEx.BatcherSup.html#terminate_batchers/0"},{"type":"module","title":"LogflareEx.Client","doc":"A `LogflareEx.Client` contains all configuration used for making API requests, whether batched or not.\n\n#","ref":"LogflareEx.Client.html"},{"type":"module","title":"Application-level Configuration - LogflareEx.Client","doc":"Application-wide configuration can be set in `config.exs`:\n\n```elixir\nconfig :logflare_ex,\n  api_key: \"...\",\n  source_token: \"...\"\n```\n\n#","ref":"LogflareEx.Client.html#module-application-level-configuration"},{"type":"module","title":"Runtime Configuration - LogflareEx.Client","doc":"All configuration options can be overridden at runtime. This is through the use of the `LogflareEx.Client` struct.\n\nTo create a new client with a custom configuration, use `LogflareEx.client/1`:\n\n```elixir\n# To create a client from the application-level configuration.\niex> default_client = LogflareEx.client()\n%LogflareEx.Client{...}\n\n# To create a client with runtime overrides\niex> client = LogflareEx.client(source_token: \"...\")\n%LogflareEx.Client{...}\n\n# use the runtime client\niex> LogflareEx.send_batched_event(client, %{...})\n:ok\n```\n\n#","ref":"LogflareEx.Client.html#module-runtime-configuration"},{"type":"module","title":"Options - LogflareEx.Client","doc":"For every configuration, either `:source_token` or `:source_name` must be provided.\n\n- `:api_key`: **Required**. Public API key.\n- `:api_url`: Custom Logflare endpoint, for self-hosting. Defaults to `https//api.logflare.app`.\n- `:source_token`: Source UUID. Mutually exclusive with `:source_name`\n- `:source_name`: Source name. Mutually exclusive with `:source_token`\n- `:on_error`: mfa callback for handling API errors. Must be 1 arity.\n- `:auto_flush`: Used for batching. Enables automatic flushing. If disabled, `LogflareEx.flush/1` must be called.\n- `:flush_interval`: Used for batching. Flushes cached events at the provided interval.\n- `:batch_size`: Used for batching. It is the maximum number of events send per API request.","ref":"LogflareEx.Client.html#module-options"},{"type":"function","title":"LogflareEx.Client.get_config_value/1","doc":"","ref":"LogflareEx.Client.html#get_config_value/1"},{"type":"function","title":"LogflareEx.Client.new/1","doc":"","ref":"LogflareEx.Client.html#new/1"},{"type":"function","title":"LogflareEx.Client.validate_client/1","doc":"","ref":"LogflareEx.Client.html#validate_client/1"},{"type":"type","title":"LogflareEx.Client.t/0","doc":"Logflare client","ref":"LogflareEx.Client.html#t:t/0"},{"type":"module","title":"LogflareEx.LoggerBackend","doc":"Implements `:gen_event` behaviour, handles incoming Logger messages.\n\n\n#","ref":"LogflareEx.LoggerBackend.html"},{"type":"module","title":"Usage - LogflareEx.LoggerBackend","doc":"Add the following to your config.exs:\n```elixir\nconfig :logger\n  backends: [..., LogflareEx.LoggerBackend]\n```\nYou can then log as per normal:\n\n```elixir\nrequire Logger\nLogger.info(\"some event\", my: \"data\")\n```\n\n#","ref":"LogflareEx.LoggerBackend.html#module-usage"},{"type":"module","title":"Metadata - LogflareEx.LoggerBackend","doc":"To add custom metadata, use `Logger.metadata/1`\n```elixir\nLogger.metadata(some: \"data\")\n```\n\nOn the payload sent to Logflare API, the above metadata will be merged into the `metadata` field, resulting in the following schema path `metadata.some`.\n\nAny additional Logger metadata provided in the `Logger.info/2` call will be merged together by Logger.\nThis merging is not handled by the library.\n\nThis backend also enriches the log event with certaon fields:\n\n- `metadata.context` - context of the log event, including vm information, pid, module, etc.\n- `metadata.level` - log level, corresponding to the Logger level set.\n- `metadata.stacktrace` - stacktrace of the error, if the event is an error.\n\n#","ref":"LogflareEx.LoggerBackend.html#module-metadata"},{"type":"module","title":"JSON-Encoding Conversions - LogflareEx.LoggerBackend","doc":"To ensure that payload sent to Logflare API is JSON serializable and searchable by the selected backend, certain conversions are applied to the terms received.\n\n- atoms are converted to strings.\n  For example, `:value` to `\"value\"`.\n- charlists are converted to strings\n  For example, `'value'` to `\"value\"`.\n- tuples converted to lists\n  For example, `{1, 2}` to `[1, 2]`.\n- keyword lists converted to maps\n  For example, `[my: :value]` to `%{\"my\"=> \"value\"}`.\n- structs converted to maps\n  For example, `%MyStruct{}` to `%{some: \"default key\"}`.\n- NaiveDateTime and DateTime are converted using the String.Chars protocol\n  For example, `%NaiveDateTime{}` to `1337-04-19 00:00:00`.\n- pids are converted to strings\n  For example, `#PID ` to `\" \"`","ref":"LogflareEx.LoggerBackend.html#module-json-encoding-conversions"},{"type":"function","title":"LogflareEx.LoggerBackend.code_change/3","doc":"","ref":"LogflareEx.LoggerBackend.html#code_change/3"},{"type":"function","title":"LogflareEx.LoggerBackend.handle_call/2","doc":"","ref":"LogflareEx.LoggerBackend.html#handle_call/2"},{"type":"function","title":"LogflareEx.LoggerBackend.handle_event/2","doc":"","ref":"LogflareEx.LoggerBackend.html#handle_event/2"},{"type":"function","title":"LogflareEx.LoggerBackend.handle_info/2","doc":"","ref":"LogflareEx.LoggerBackend.html#handle_info/2"},{"type":"function","title":"LogflareEx.LoggerBackend.init/1","doc":"","ref":"LogflareEx.LoggerBackend.html#init/1"},{"type":"function","title":"LogflareEx.LoggerBackend.terminate/2","doc":"","ref":"LogflareEx.LoggerBackend.html#terminate/2"},{"type":"type","title":"LogflareEx.LoggerBackend.level/0","doc":"","ref":"LogflareEx.LoggerBackend.html#t:level/0"},{"type":"type","title":"LogflareEx.LoggerBackend.log_msg/0","doc":"","ref":"LogflareEx.LoggerBackend.html#t:log_msg/0"},{"type":"type","title":"LogflareEx.LoggerBackend.message/0","doc":"","ref":"LogflareEx.LoggerBackend.html#t:message/0"},{"type":"type","title":"LogflareEx.LoggerBackend.metadata/0","doc":"","ref":"LogflareEx.LoggerBackend.html#t:metadata/0"},{"type":"module","title":"LogflareEx.LoggerBackend.Stacktrace","doc":"Handles stacktrace formatting for logged exceptions","ref":"LogflareEx.LoggerBackend.Stacktrace.html"},{"type":"function","title":"LogflareEx.LoggerBackend.Stacktrace.format/1","doc":"","ref":"LogflareEx.LoggerBackend.Stacktrace.html#format/1"},{"type":"module","title":"LogflareEx.Repo","doc":"","ref":"LogflareEx.Repo.html"},{"type":"function","title":"LogflareEx.Repo.aggregate/3","doc":"","ref":"LogflareEx.Repo.html#aggregate/3"},{"type":"function","title":"LogflareEx.Repo.aggregate/4","doc":"","ref":"LogflareEx.Repo.html#aggregate/4"},{"type":"function","title":"LogflareEx.Repo.all/2","doc":"","ref":"LogflareEx.Repo.html#all/2"},{"type":"function","title":"LogflareEx.Repo.checked_out?/0","doc":"","ref":"LogflareEx.Repo.html#checked_out?/0"},{"type":"function","title":"LogflareEx.Repo.checkout/2","doc":"","ref":"LogflareEx.Repo.html#checkout/2"},{"type":"function","title":"LogflareEx.Repo.child_spec/1","doc":"","ref":"LogflareEx.Repo.html#child_spec/1"},{"type":"function","title":"LogflareEx.Repo.config/0","doc":"","ref":"LogflareEx.Repo.html#config/0"},{"type":"function","title":"LogflareEx.Repo.default_options/1","doc":"","ref":"LogflareEx.Repo.html#default_options/1"},{"type":"function","title":"LogflareEx.Repo.delete/2","doc":"","ref":"LogflareEx.Repo.html#delete/2"},{"type":"function","title":"LogflareEx.Repo.delete!/2","doc":"","ref":"LogflareEx.Repo.html#delete!/2"},{"type":"function","title":"LogflareEx.Repo.delete_all/2","doc":"","ref":"LogflareEx.Repo.html#delete_all/2"},{"type":"function","title":"LogflareEx.Repo.exists?/2","doc":"","ref":"LogflareEx.Repo.html#exists?/2"},{"type":"function","title":"LogflareEx.Repo.get/3","doc":"","ref":"LogflareEx.Repo.html#get/3"},{"type":"function","title":"LogflareEx.Repo.get!/3","doc":"","ref":"LogflareEx.Repo.html#get!/3"},{"type":"function","title":"LogflareEx.Repo.get_by/3","doc":"","ref":"LogflareEx.Repo.html#get_by/3"},{"type":"function","title":"LogflareEx.Repo.get_by!/3","doc":"","ref":"LogflareEx.Repo.html#get_by!/3"},{"type":"function","title":"LogflareEx.Repo.get_dynamic_repo/0","doc":"","ref":"LogflareEx.Repo.html#get_dynamic_repo/0"},{"type":"function","title":"LogflareEx.Repo.insert/2","doc":"","ref":"LogflareEx.Repo.html#insert/2"},{"type":"function","title":"LogflareEx.Repo.insert!/2","doc":"","ref":"LogflareEx.Repo.html#insert!/2"},{"type":"function","title":"LogflareEx.Repo.insert_all/3","doc":"","ref":"LogflareEx.Repo.html#insert_all/3"},{"type":"function","title":"LogflareEx.Repo.insert_or_update/2","doc":"","ref":"LogflareEx.Repo.html#insert_or_update/2"},{"type":"function","title":"LogflareEx.Repo.insert_or_update!/2","doc":"","ref":"LogflareEx.Repo.html#insert_or_update!/2"},{"type":"function","title":"LogflareEx.Repo.load/2","doc":"","ref":"LogflareEx.Repo.html#load/2"},{"type":"function","title":"LogflareEx.Repo.one/2","doc":"","ref":"LogflareEx.Repo.html#one/2"},{"type":"function","title":"LogflareEx.Repo.one!/2","doc":"","ref":"LogflareEx.Repo.html#one!/2"},{"type":"function","title":"LogflareEx.Repo.preload/3","doc":"","ref":"LogflareEx.Repo.html#preload/3"},{"type":"function","title":"LogflareEx.Repo.prepare_query/3","doc":"","ref":"LogflareEx.Repo.html#prepare_query/3"},{"type":"function","title":"LogflareEx.Repo.put_dynamic_repo/1","doc":"","ref":"LogflareEx.Repo.html#put_dynamic_repo/1"},{"type":"function","title":"LogflareEx.Repo.reload/2","doc":"","ref":"LogflareEx.Repo.html#reload/2"},{"type":"function","title":"LogflareEx.Repo.reload!/2","doc":"","ref":"LogflareEx.Repo.html#reload!/2"},{"type":"function","title":"LogflareEx.Repo.start_link/1","doc":"","ref":"LogflareEx.Repo.html#start_link/1"},{"type":"function","title":"LogflareEx.Repo.stop/1","doc":"","ref":"LogflareEx.Repo.html#stop/1"},{"type":"function","title":"LogflareEx.Repo.stream/2","doc":"","ref":"LogflareEx.Repo.html#stream/2"},{"type":"function","title":"LogflareEx.Repo.update/2","doc":"","ref":"LogflareEx.Repo.html#update/2"},{"type":"function","title":"LogflareEx.Repo.update!/2","doc":"","ref":"LogflareEx.Repo.html#update!/2"},{"type":"function","title":"LogflareEx.Repo.update_all/3","doc":"","ref":"LogflareEx.Repo.html#update_all/3"},{"type":"module","title":"LogflareEx.TelemetryReporter","doc":"A TelemetryReporter for attaching to metrics created from `:telemetry_metrics`.\nTelemetry events are sent to the Logflare API as is.\n\nAdd the following to your `mix.exs`\n```elixir\ndef deps do\n  [\n      {:telemetry, \"~> 1.0\"},\n      {:telemetry_metrics, \"~> 0.6.1\"},\n  ]\nend\n```\n\nThereafter, add the `LogflareEx.TelemetryReporter` to your supervision tree:\n\n```elixir\n  # application.ex\n  children = [\n    {LogflareEx.TelemetryReporter, metrics: [\n      last_value(\"some.event.stop.duration\")\n    ]}\n  ]\n  ...\n```\n\nThe `LogflareEx.TelemetryReporter` will attach to all provided metrics.","ref":"LogflareEx.TelemetryReporter.html"},{"type":"function","title":"LogflareEx.TelemetryReporter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LogflareEx.TelemetryReporter.html#child_spec/1"},{"type":"function","title":"LogflareEx.TelemetryReporter.handle_attach/4","doc":"`:telemetry.attach/4` callback for allowing attaching to telemetry events.\nTelemetry events attached this way are batched to Logflare.","ref":"LogflareEx.TelemetryReporter.html#handle_attach/4"},{"type":"function","title":"LogflareEx.TelemetryReporter.start_link/1","doc":"","ref":"LogflareEx.TelemetryReporter.html#start_link/1"}],"content_type":"text/markdown"}